[PolyLoss](https://arxiv.org/abs/2204.12511) implementation using PyTorch

### Install

```bash
pip install polyloss
```

### Usage

```python
from polyloss import PolyLoss

...
criterion = PolyLoss(num_classes=1000)
...
```
